@@ -456,7 +456,7 @@ module Sequel
               [pk]
             elsif !(pkc = generator.constraints.select{|con| con[:type] == :primary_key}).empty?
               pkc.first[:columns]
-            elsif !(pkc = generator.columns.select{|con| con[:primary_key] == true}).empty?
+            elsif !(pkc = generator.columns.select{|con| con[:primary_key]}).empty?
               pkc.map{|c| c[:name]}
             end
           else
@@ -787,7 +787,7 @@ module Sequel
 
       # Return a cloned dataset which will use LOCK IN SHARE MODE to lock returned rows.
       def for_share
-        lock_style(:share)
+        cached_lock_style_dataset(:_for_share_ds, :share)
       end
 
       # Adds full text filter
